@@ -1,5 +1,5 @@
 package App::Munner::Runner;
-$App::Munner::Runner::VERSION = '0.54';
+$App::Munner::Runner::VERSION = '0.55';
 use Daemon::Control;
 use Mo qw( builder );
 
@@ -36,6 +36,17 @@ sub _build_env {
     return { map { my ( $key, $value ) = %$_ } @{ $conf->{env} } };
 }
 
+has fork_mode => (
+    is      => "ro",
+    isa     => "Int",
+    builder => "_build_fork_mode",
+);
+
+sub _build_fork_mode {
+    my $self = shift;
+    return $self->env->{TERMINAL} ? 1 : ( $self->todo =~ /start|duck/ ? 2 : 1 );
+}
+
 has user => (
     is      => "ro",
     isa     => "Str",
@@ -83,6 +94,26 @@ sub _build_sys_gid {
     shift->sys_user_info->{gid};
 }
 
+has log_dir => (
+    is      => "ro",
+    isa     => "Str",
+    builder => "_build_log_dir",
+);
+
+sub _build_log_dir {
+    my $self = shift;
+    my $env = $self->env;
+    my $log_dir = $env->{LOG_DIR}
+        or return q{};
+    if ( $log_dir !~/^\// ) {
+        my $base_dir = $self->base_dir || q{};
+        $log_dir = "$base_dir/$log_dir";
+    }
+    die "LOG_DIR: $log_dir is not found\n"
+        if !-d $log_dir;
+    return $log_dir;
+}
+
 has pid_file => (
     is      => "ro",
     isa     => "Str",
@@ -91,7 +122,7 @@ has pid_file => (
 
 sub _build_pid_file {
     my $self     = shift;
-    my $base_dir = $self->base_dir || q{};
+    my $base_dir = $self->log_dir || $self->base_dir || q{};
     my $app      = $self->name;
     return $self->_touch( $self->env->{PID_FILE} || "$base_dir/$app.pid" );
 }
@@ -104,7 +135,7 @@ has error_log => (
 
 sub _build_error_log {
     my $self     = shift;
-    my $base_dir = $self->base_dir || q{};
+    my $base_dir = $self->log_dir || $self->base_dir || q{};
     my $app      = $self->name;
     return $self->_touch( $self->env->{ERROR_LOG}
           || "$base_dir/$app.error.log" );
@@ -118,7 +149,7 @@ has access_log => (
 
 sub _build_access_log {
     my $self     = shift;
-    my $base_dir = $self->base_dir || q{};
+    my $base_dir = $self->log_dir || $self->base_dir || q{};
     my $app      = $self->name;
     return $self->_touch( $self->env->{ACCESS_LOG}
           || "$base_dir/$app.access.log" );
@@ -152,8 +183,6 @@ sub _build_daemon {
     $self->_touch($cmd)
       if -f $cmd;
 
-    my $fork_mode = $self->todo =~ /start|duck/ ? 2 : 1;
-
     my $daemon = Daemon::Control->new(
         {
             name        => $app,
@@ -166,7 +195,7 @@ sub _build_daemon {
             pid_file    => $self->pid_file,
             stderr_file => $self->error_log,
             stdout_file => $self->access_log,
-            fork        => $fork_mode,
+            fork        => $self->fork_mode,
             uid         => $info->{uid},
             gid         => $info->{gid},
         }
